@@ -44,4 +44,25 @@ namespace R_BLAS_LAPACK {
   double ddot(
       const int *n, const double *dx, const int *incx,
       const double *dy, const int *incy);
+
+  void dgetrf(
+      const int* m, const int* n, double* a, const int* lda,int* ipiv,
+      int* info);
+
+  void dgetrs(
+      const char* trans, const int* n, const int* nrhs, const double* a,
+      const int* lda, const int* ipiv, double* b, const int* ldb, int* info);
+
+  void dormqr(const char* side, const char* trans,
+              const int* m, const int* n, const int* k,
+              const double* a, const int* lda,
+              const double* tau, double* c, const int* ldc,
+              double* work, const int* lwork, int* info);
+
+  void dgeqp3(const int* m, const int* n, double* a, const int* lda,
+              int* jpvt, double* tau, double* work, const int* lwork,
+              int* info);
+
+  void dgetri(const int*, double*, const int*,
+              int*, double*, const int*, int*);
 }
